@@ -14,7 +14,7 @@ from networkx import DiGraph, MultiDiGraph
 
 class ProbabilityMarkovChain:
 
-    def __init__(self, top: int = 3):
+    def __init__(self, top: int = 5):
         self.markov_chain_graph = None
         self.multi_di_graph = MultiDiGraph()
         self.top = top  # top x probability for generating a string
@@ -69,7 +69,7 @@ class ProbabilityMarkovChain:
         while len(out_str) < length:
             n_w = [(n, model[char][n]['weight']) for n in model[char]]
             n_w.sort(key=lambda tup: tup[1], reverse=True)
-            char = secrets.choice(n_w[:self.top])[0]
+            char = secrets.choice(list(set(n_w[:self.top])))[0]
             out_str.append(char)
         return ''.join(out_str)
 
@@ -101,7 +101,8 @@ class ProbabilityMarkovChain:
 class GibberishScore:
 
     def __init__(self, model_pickle: str):
-        self.pmc: ProbabilityMarkovChain = pickle.load(open(model_pickle, 'rb'))
+        with open(model_pickle, 'rb') as fp:
+            self.pmc: ProbabilityMarkovChain = pickle.load(fp)
         self.deterministic_string_mapping = dict()
         self.threshold = None
 
@@ -117,7 +118,8 @@ class GibberishScore:
             dngs = list(self.pmc.get_nongibberish_string(len(in_str)+1))
             for i in [i for i, c in enumerate(in_str) if c.isupper()]:
                 dngs[i] = dngs[i].upper()
-            self.deterministic_string_mapping[in_str] = ''.join(dngs)
+            dngs = ''.join(dngs)
+            self.deterministic_string_mapping[in_str] = dngs
         return dngs
 
     def is_gibberish(self, input_string: str) -> bool:
